@@ -45,15 +45,21 @@ class MobileCommand(object):
     IS_APP_INSTALLED = 'isAppInstalled'
     INSTALL_APP = 'installApp'
     REMOVE_APP = 'removeApp'
+    TERMINATE_APP = 'terminateApp'
+    ACTIVATE_APP = 'activateApp'
+    QUERY_APP_STATE = 'queryAppState'
     LAUNCH_APP = 'launchApp'
     CLOSE_APP = 'closeApp'
     END_TEST_COVERAGE = 'endTestCoverage'
     LOCK = 'lock'
+    UNLOCK = 'unlock'
+    IS_LOCKED = 'isLocked'
     SHAKE = 'shake'
     TOUCH_ID = 'touchId'
     TOGGLE_TOUCH_ID_ENROLLMENT = 'toggleTouchIdEnrollment'
     RESET = 'reset'
     HIDE_KEYBOARD = 'hideKeyboard'
+    IS_KEYBOARD_SHOWN = 'isKeyboardShown'
     REPLACE_KEYS = 'replaceKeys'
     START_ACTIVITY = 'startActivity'
     GET_SETTINGS = 'getSettings'
@@ -61,3 +67,8 @@ class MobileCommand(object):
     SET_LOCATION = 'setLocation'
     GET_DEVICE_TIME = 'getDeviceTime'
     CLEAR = 'clear'
+    START_RECORDING_SCREEN = 'startRecordingScreen'
+    STOP_RECORDING_SCREEN = 'stopRecordingScreen'
+    SET_CLIPBOARD = 'setClipboard'
+    GET_CLIPBOARD = 'getClipboard'
+    COMPARE_IMAGES = 'compareImages'
