@@ -41,6 +41,50 @@ class WebElement(SeleniumWebElement):
         """
         return self.find_elements(by=By.IOS_UIAUTOMATION, value=uia_string)
 
+    def find_element_by_ios_predicate(self, predicate_string):
+        """Find an element by ios predicate string.
+
+        :Args:
+         - predicate_string - The predicate string
+
+        :Usage:
+            driver.find_element_by_ios_predicate('label == "myLabel"')
+        """
+        return self.find_element(by=By.IOS_PREDICATE, value=predicate_string)
+
+    def find_elements_by_ios_predicate(self, predicate_string):
+        """Finds elements by ios predicate string.
+
+        :Args:
+         - predicate_string - The predicate string
+
+        :Usage:
+            driver.find_elements_by_ios_predicate('label == "myLabel"')
+        """
+        return self.find_elements(by=By.IOS_PREDICATE, value=predicate_string)
+
+    def find_element_by_ios_class_chain(self, class_chain_string):
+        """Find an element by ios class chain string.
+
+        :Args:
+         - class_chain_string - The class chain string
+
+        :Usage:
+            driver.find_element_by_ios_class_chain('XCUIElementTypeWindow/XCUIElementTypeButton[3]')
+        """
+        return self.find_element(by=By.IOS_CLASS_CHAIN, value=class_chain_string)
+
+    def find_elements_by_ios_class_chain(self, class_chain_string):
+        """Finds elements by ios class chain string.
+
+        :Args:
+         - class_chain_string - The class chain string
+
+        :Usage:
+            driver.find_elements_by_ios_class_chain('XCUIElementTypeWindow[2]/XCUIElementTypeAny[-2]')
+        """
+        return self.find_elements(by=By.IOS_CLASS_CHAIN, value=class_chain_string)
+
     def find_element_by_android_uiautomator(self, uia_string):
         """Finds element by uiautomator in Android.
 
@@ -122,3 +166,10 @@ class WebElement(SeleniumWebElement):
         }
         self._execute(Command.SET_IMMEDIATE_VALUE, data)
         return self
+
+    def clear(self):
+        """Clears text.
+        """
+        data = {'id': self.id}
+        self._execute(Command.CLEAR, data)
+        return self
